==> nextcloud-29.0.12.tgz: nextcloud/apps/files_external/l10n/lt_LT.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Suteikti prieigą",
    "Error configuring OAuth1" : "Klaida, konfigūruojant OAuth1",
    "Please provide a valid app key and secret." : "Prašome naudoti teisingus trečiųjų šalių programinės įrangos identifikacijos numerį ir slaptažodį.",
    "Error configuring OAuth2" : "Klaida, konfigūruojant OAuth2",
    "Generate keys" : "Generuoti raktus",
    "Error generating key pair" : "Klaida generuojant raktų porą",
    "Storage with ID \"%d\" not found" : "Nerasta saugykla su identifikacijos numeriu \"%d\"",
    "Invalid backend or authentication mechanism class" : "Netinkama programinio kodo klasė realizuoja prisijungimo mechanizmą",
    "Invalid mount point" : "Neteisingas prijungimo taškas",
    "Objectstore forbidden" : "Objektų saugykla yra neprieinama",
    "Not permitted to use backend \"%s\"" : "Neleidžiama naudoti vidinės pusės „%s“",
    "Not permitted to use authentication mechanism \"%s\"" : "Neleidžiama naudoti tapatybės nustatymo mechanizmo „%s“",
    "Unsatisfied backend parameters" : " Netinkami posistemės parametrai",
    "Unsatisfied authentication mechanism parameters" : "Netinkami parametrai perduoti į prisijungimo mechanizmą",
    "Insufficient data: %s" : "Trūksta duomenų: %s",
    "%s" : "%s",
    "Access key" : "Prieigos raktas",
    "Secret key" : "Slaptasis raktas",
    "Builtin" : "Įtaisytasis",
    "None" : "Nėra",
    "OAuth1" : "OAuth1",
    "App key" : "Trečiųjų šalių programinės įrangos identifikacijos raktas",
    "App secret" : "Trečiųjų šalių programinės įrangos slaptažodis",
    "OAuth2" : "OAuth2",
    "Client ID" : "Kliento ID",
    "Client secret" : "Trečiųjų šalių programinės įrangos kliento identifikacijos raktas",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Prisijungti",
    "Password" : "Slaptažodis",
    "Tenant name" : "Laikino valdytojo vardas",
    "Identity endpoint URL" : "Identiteto URL",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domenas",
    "Rackspace" : "Rackspace",
    "API key" : "API raktas",
    "Global credentials" : "Visuotiniai prisijungimo duomenys",
    "Log-in credentials, save in database" : "Prisijungimo duomenys, saugoti duomenų bazėje",
    "Log-in credentials, save in session" : "Prisijungimo duomenys, saugoti sesijoje",
    "RSA public key" : "RSA viešasis raktas",
    "Public key" : "Viešasis raktas",
    "RSA private key" : "RSA privatusis raktas",
    "Private key" : "Privatusis raktas",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Amazon S3 saugykla",
    "Hostname" : "Domeno vardas",
    "Port" : "Prievadas",
    "Region" : "Regionas",
    "Enable SSL" : "Įjungti SSL",
    "Enable Path Style" : "Amazon S3 kelias",
    "SSE-C encryption key" : "SSE-C šifravimo raktas",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Nuotolinis poaplankis",
    "Secure https://" : "Saugus https://",
    "FTP" : "FTP",
    "Host" : "Domenas",
    "Secure ftps://" : "Saugus ftps://",
    "Local" : "Vietinis",
    "Location" : "Vieta",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Šaknis",
    "SFTP with secret key login" : "SFTP protokolas su prisijungimu",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Bendrinti",
    "Show hidden files" : "Rodyti paslėptus failus",
    "Timeout" : "Pasibaigė laikas",
    "Service name" : "Paslaugos vardas",
    "Request timeout (seconds)" : "Prisijungimo laikas (sekundėmis)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL palaikymas yra neįjungtas arba neįdiegtas į PHP. %s prijungimas neįmanomas. Paprašykite sistemos administratoriaus pagalbos.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP palaikymas yra neįjungtas arba neįdiegtas į PHP. %s prijungimas neįmanomas. Paprašykite sistemos administratoriaus pagalbos.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" nėra įdiegtas. %2$s prijungimas yra neįmanomas. Paprašykite savo sistemos administratoriaus, kad jį įdiegtų.",
    "External storage" : "Išorinė saugykla",
    "External storage support" : "Išorinės saugyklos priežiūra",
    "Submit" : "Pateikti",
    "New configuration successfully saved" : "Nauja konfigūracija sėkmingai įrašyta",
    "External mount error" : "Išorinio prijungimo klaida",
    "Storage type" : "Saugyklos tipas",
    "Unknown" : "Nežinoma",
    "Scope" : "Leidimas",
    "Personal" : "Asmeniniai",
    "System" : "Sistema",
    "(Group)" : "(Grupė)",
    "Compatibility with Mac NFD encoding (slow)" : "Suderinamumas su Mac NFD koduote (lėtai)",
    "Enable encryption" : "Įjungti šifravimą",
    "Enable previews" : "Leisti peržiūras",
    "Enable sharing" : "Leisti bendrinti",
    "Check for changes" : "Patikrinti ar nėra pakeitimų",
    "Never" : "Niekada",
    "Once every direct access" : "Kartą per tiesioginę peržiūrą",
    "Read only" : "Tik skaitymui",
    "Disconnect" : "Atsijungti",
    "Admin defined" : "Administratorius apibrėžtas",
    "Delete storage?" : "Ištrinti saugyklą?",
    "Click to recheck the configuration" : "Spustelėkite norėdami iš naujo patikrinti konfigūraciją",
    "Saved" : "Įrašyta",
    "Saving …" : "Įrašoma …",
    "Save" : "Įrašyti",
    "No external storage configured or you don't have the permission to configure them" : "Nėra sukonfigūruota jokia išorinė saugykla arba jūs neturite leidimo jų konfigūruoti",
    "Open documentation" : "Atverti dokumentaciją",
    "Folder name" : "Aplanko pavadinimas",
    "Authentication" : "Prisijungimas",
    "Configuration" : "Konfigūracija",
    "Available for" : "Prieinamas",
    "Add storage" : "Pridėti saugyklą",
    "Advanced settings" : "Išplėstiniai nustatymai"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/files_external/l10n/lt_LT.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Suteikti prieigą",
    "Error configuring OAuth1" : "Klaida, konfigūruojant OAuth1",
    "Please provide a valid app key and secret." : "Prašome naudoti teisingus trečiųjų šalių programinės įrangos identifikacijos numerį ir slaptažodį.",
    "Error configuring OAuth2" : "Klaida, konfigūruojant OAuth2",
    "Generate keys" : "Generuoti raktus",
    "Error generating key pair" : "Klaida generuojant raktų porą",
    "Storage with ID \"%d\" not found" : "Nerasta saugykla su identifikacijos numeriu \"%d\"",
    "Invalid backend or authentication mechanism class" : "Netinkama programinio kodo klasė realizuoja prisijungimo mechanizmą",
    "Invalid mount point" : "Neteisingas prijungimo taškas",
    "Objectstore forbidden" : "Objektų saugykla yra neprieinama",
    "Not permitted to use backend \"%s\"" : "Neleidžiama naudoti vidinės pusės „%s“",
    "Not permitted to use authentication mechanism \"%s\"" : "Neleidžiama naudoti tapatybės nustatymo mechanizmo „%s“",
    "Unsatisfied backend parameters" : " Netinkami posistemės parametrai",
    "Unsatisfied authentication mechanism parameters" : "Netinkami parametrai perduoti į prisijungimo mechanizmą",
    "Insufficient data: %s" : "Trūksta duomenų: %s",
    "%s" : "%s",
    "Access key" : "Prieigos raktas",
    "Secret key" : "Slaptasis raktas",
    "Builtin" : "Įtaisytasis",
    "None" : "Nėra",
    "OAuth1" : "OAuth1",
    "App key" : "Trečiųjų šalių programinės įrangos identifikacijos raktas",
    "App secret" : "Trečiųjų šalių programinės įrangos slaptažodis",
    "OAuth2" : "OAuth2",
    "Client ID" : "Kliento ID",
    "Client secret" : "Trečiųjų šalių programinės įrangos kliento identifikacijos raktas",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Prisijungti",
    "Password" : "Slaptažodis",
    "Tenant name" : "Laikino valdytojo vardas",
    "Identity endpoint URL" : "Identiteto URL",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domenas",
    "Rackspace" : "Rackspace",
    "API key" : "API raktas",
    "Global credentials" : "Visuotiniai prisijungimo duomenys",
    "Log-in credentials, save in database" : "Prisijungimo duomenys, saugoti duomenų bazėje",
    "Log-in credentials, save in session" : "Prisijungimo duomenys, saugoti sesijoje",
    "RSA public key" : "RSA viešasis raktas",
    "Public key" : "Viešasis raktas",
    "RSA private key" : "RSA privatusis raktas",
    "Private key" : "Privatusis raktas",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Amazon S3 saugykla",
    "Hostname" : "Domeno vardas",
    "Port" : "Prievadas",
    "Region" : "Regionas",
    "Enable SSL" : "Įjungti SSL",
    "Enable Path Style" : "Amazon S3 kelias",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Nuotolinis poaplankis",
    "Secure https://" : "Saugus https://",
    "FTP" : "FTP",
    "Host" : "Domenas",
    "Secure ftps://" : "Saugus ftps://",
    "Local" : "Vietinis",
    "Location" : "Vieta",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Šaknis",
    "SFTP with secret key login" : "SFTP protokolas su prisijungimu",
    "Share" : "Bendrinti",
    "Show hidden files" : "Rodyti paslėptus failus",
    "Timeout" : "Pasibaigė laikas",
    "Service name" : "Paslaugos vardas",
    "Request timeout (seconds)" : "Prisijungimo laikas (sekundėmis)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL palaikymas yra neįjungtas arba neįdiegtas į PHP. %s prijungimas neįmanomas. Paprašykite sistemos administratoriaus pagalbos.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP palaikymas yra neįjungtas arba neįdiegtas į PHP. %s prijungimas neįmanomas. Paprašykite sistemos administratoriaus pagalbos.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" nėra įdiegtas. %2$s prijungimas yra neįmanomas. Paprašykite savo sistemos administratoriaus, kad jį įdiegtų.",
    "External storage" : "Išorinė saugykla",
    "External storage support" : "Išorinės saugyklos priežiūra",
    "Submit" : "Pateikti",
    "External mount error" : "Išorinio prijungimo klaida",
    "Storage type" : "Saugyklos tipas",
    "Unknown" : "Nežinoma",
    "Scope" : "Leidimas",
    "Personal" : "Asmeniniai",
    "System" : "Sistema",
    "(Group)" : "(Grupė)",
    "Compatibility with Mac NFD encoding (slow)" : "Suderinamumas su Mac NFD koduote (lėtai)",
    "Enable encryption" : "Įjungti šifravimą",
    "Enable previews" : "Leisti peržiūras",
    "Enable sharing" : "Leisti bendrinti",
    "Check for changes" : "Patikrinti ar nėra pakeitimų",
    "Never" : "Niekada",
    "Once every direct access" : "Kartą per tiesioginę peržiūrą",
    "Read only" : "Tik skaitymui",
    "Disconnect" : "Atsijungti",
    "Admin defined" : "Administratorius apibrėžtas",
    "Delete storage?" : "Ištrinti saugyklą?",
    "Click to recheck the configuration" : "Spustelėkite norėdami iš naujo patikrinti konfigūraciją",
    "Saved" : "Įrašyta",
    "Saving …" : "Įrašoma …",
    "Save" : "Įrašyti",
    "No external storage configured or you don't have the permission to configure them" : "Nėra sukonfigūruota jokia išorinė saugykla arba jūs neturite leidimo jų konfigūruoti",
    "Open documentation" : "Atverti dokumentaciją",
    "Folder name" : "Aplanko pavadinimas",
    "Authentication" : "Prisijungimas",
    "Configuration" : "Konfigūracija",
    "Available for" : "Prieinamas",
    "Add storage" : "Pridėti saugyklą",
    "Advanced settings" : "Išplėstiniai nustatymai",
    "Storage with ID \"%d\" is not user editable" : "Naudotojai negali redaguoti saugyklos identifikuotos kaip \"%d\"",
    "Username" : "Naudotojo vardas",
    "Username and password" : "Naudotojo vardas ir slaptažodis",
    "User entered, store in database" : "Naudotojas įvestas, saugoti duomenų bazėje",
    "Username as share" : "Dalinimosi vardas kaip ir vartotojo vardas",
    "All users" : "Visi naudotojai",
    "Allow users to mount external storage" : "Leisti naudotojams prijungti išorines saugyklas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
